Geometry Module
===============

Something about the functionality of the Geometry module

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   Analyser
   Detector
   GeometryConcept
   Instrument
   InstrumentXML
   Wedge
   


